@@ -21,8 +21,9 @@
 #define FINANCIAL_H
 
 #include "mp.h"
+#include "math-equation.h"
 
-void do_finc_expression(int function, MPNumber *arg1, MPNumber *arg2, MPNumber *arg3, MPNumber *arg4);
+void do_finc_expression(MathEquation *equation, int function, MPNumber *arg1, MPNumber *arg2, MPNumber *arg3, MPNumber *arg4);
 
 enum finc_dialogs {
     FINC_CTRM_DIALOG,
