@@ -20,11 +20,13 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#include <locale.h>
+#include <glib/gi18n.h>
 
-#include "currency.h"
 #include "unittest.h"
 #include "math-window.h"
 #include "mp-equation.h"
+#include "unit-manager.h"
 
 static GSettings *settings = NULL;
 
@@ -38,18 +40,26 @@ version(const gchar *progname)
 }
 
 
+static int
+do_convert(const MPNumber *x, const char *x_units, const char *z_units, MPNumber *z, void *data)
+{
+    return unit_manager_convert_by_symbol(unit_manager_get_default(), x, x_units, z_units, z);
+}
+
+
 static void
 solve(const char *equation)
 {
     MPEquationOptions options;
     MPErrorCode error;
     MPNumber result;
-    char result_str[1024];
+    char *result_str;
 
     memset(&options, 0, sizeof(options));
     options.base = 10;
     options.wordlen = 32;
     options.angle_units = MP_DEGREES;
+    options.convert = do_convert;
 
     error = mp_equation_parse(equation, &options, &result, NULL);
     if(error == PARSER_ERR_MP) {
@@ -61,7 +71,7 @@ solve(const char *equation)
         exit(1);
     }
     else {
-        mp_cast_to_string(&result, 10, 10, 9, 1, result_str, 1024);
+        result_str = mp_serializer_to_string(mp_serializer_new(MP_DISPLAY_FORMAT_AUTOMATIC, 10, 9), &result);
         printf("%s\n", result_str);
         exit(0);
     }
@@ -193,9 +203,10 @@ quit_cb(MathWindow *window)
     g_settings_set_enum(settings, "button-mode", math_buttons_get_mode(buttons));
     g_settings_set_string(settings, "source-currency", math_equation_get_source_currency(equation));
     g_settings_set_string(settings, "target-currency", math_equation_get_target_currency(equation));
+    g_settings_set_string(settings, "source-units", math_equation_get_source_units(equation));
+    g_settings_set_string(settings, "target-units", math_equation_get_target_units(equation));
     g_settings_sync();
 
-    currency_free_resources();
     gtk_main_quit();
 }
 
@@ -206,13 +217,15 @@ main(int argc, char **argv)
     MathEquation *equation;
     int accuracy = 9, word_size = 64, base = 10;
     gboolean show_tsep = FALSE, show_zeroes = FALSE;
-    DisplayFormat number_format;
+    MpDisplayFormat number_format;
     MPAngleUnit angle_units;
     ButtonMode button_mode;
     gchar *source_currency, *target_currency;
+    gchar *source_units, *target_units;
 
     g_type_init();
 
+    setlocale(LC_ALL, "");
     bindtextdomain(GETTEXT_PACKAGE, LOCALE_DIR);
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
     textdomain(GETTEXT_PACKAGE);
@@ -233,6 +246,8 @@ main(int argc, char **argv)
     button_mode = g_settings_get_enum(settings, "button-mode");
     source_currency = g_settings_get_string(settings, "source-currency");
     target_currency = g_settings_get_string(settings, "target-currency");
+    source_units = g_settings_get_string(settings, "source-units");
+    target_units = g_settings_get_string(settings, "target-units");
 
     equation = math_equation_new();
     math_equation_set_accuracy(equation, accuracy);
@@ -243,8 +258,12 @@ main(int argc, char **argv)
     math_equation_set_angle_units(equation, angle_units);
     math_equation_set_source_currency(equation, source_currency);
     math_equation_set_target_currency(equation, target_currency);
+    math_equation_set_source_units(equation, source_units);
+    math_equation_set_target_units(equation, target_units);
     g_free(source_currency);
     g_free(target_currency);
+    g_free(source_units);
+    g_free(target_units);
 
     gtk_init(&argc, &argv);
 
