@@ -25,6 +25,7 @@
 #include "unittest.h"
 #include "mp-equation.h"
 #include "mp-serializer.h"
+#include "unit-manager.h"
 
 static MPEquationOptions options;
 
@@ -87,7 +88,7 @@ test(char *expression, char *expected, int expected_error)
 
     error = mp_equation_parse(expression, &options, &result, NULL);
 
-    if(error == 0) {
+    if (error == 0) {
         char *result_str;
         MpSerializer *serializer;
 
@@ -116,6 +117,13 @@ test(char *expression, char *expected, int expected_error)
 }
 
 
+static int
+do_convert(const MPNumber *x, const char *x_units, const char *z_units, MPNumber *z, void *data)
+{
+    return unit_manager_convert_by_symbol(unit_manager_get_default(), x, x_units, z_units, z);
+}
+
+
 static void
 test_conversions()
 {
@@ -123,6 +131,11 @@ test_conversions()
     options.base = 10;
     options.wordlen = 32;
     options.angle_units = MP_DEGREES;
+    options.convert = do_convert;
+  
+    /* Angle units */
+    //test("π radians in degrees", "180", 0);
+    test("100 gradians in degrees", "90", 0);
 
     /* Length */
     test("1 meter in mm", "1000", 0);  
@@ -138,8 +151,17 @@ test_conversions()
     /* Weight */
     test("1 kg in pounds", "2.204622622", 0);
   
-    /* Time */
+    /* Duration */
     test("1 minute in seconds", "60", 0);
+    test("1s in ms", "1000", 0);
+
+    /* Temperature */
+    //test("100˚C in ˚F", "", 0);
+    //test("0˚C in ˚F", "32", 0);
+    //test("0˚K in ˚C", "−273.15", 0);
+    test("100degC in degF", "212", 0);
+    test("0degC in degF", "32", 0);
+    test("0degK in degC", "−273.15", 0);
 }
 
 
